@@ -1,4 +1,4 @@
-# Copyright (C) 2005, 2006, 2007 Aaron Bentley <aaron.bentley@utoronto.ca>
+# Copyright (C) 2005, 2006, 2007 Aaron Bentley <aaron@aaronbentley.com>
 # Copyright (C) 2005, 2006 Canonical Limited.
 # Copyright (C) 2006 Michael Ellerman.
 #
@@ -441,13 +441,17 @@ class cmd_cbranch(BzrToolsCommand):
                             help="Create a lightweight checkout."), 'revision',
                      Option('files-from', type=unicode,
                             help='Accelerate checkout using files from this'
-                                 ' tree.')]
+                                 ' tree.'),
+                     Option('hardlink',
+                            help='Hard-link files from source/files-from tree'
+                            ' where posible.')]
     takes_args = ["source", "target?"]
     def run(self, source, target=None, lightweight=False, revision=None,
-            files_from=None):
+            files_from=None, hardlink=False):
         from cbranch import cbranch
         return cbranch(source, target, lightweight=lightweight,
-                       revision=revision, files_from=files_from)
+                       revision=revision, files_from=files_from,
+                       hardlink=hardlink)
 
 
 class cmd_branches(BzrToolsCommand):
@@ -637,6 +641,29 @@ class cmd_rspush(BzrToolsCommand):
                       working_tree=not no_tree)
 
 
+class cmd_link_tree(BzrToolsCommand):
+    """Hardlink matching files to another tree.
+
+    Only files with identical content and execute bit will be linked.
+    """
+    takes_args = ['location']
+
+    def run(self, location):
+        from bzrlib import workingtree
+        from bzrlib.plugins.bzrtools.link_tree import link_tree
+        target_tree = workingtree.WorkingTree.open_containing(".")[0]
+        source_tree = workingtree.WorkingTree.open(location)
+        target_tree.lock_write()
+        try:
+            source_tree.lock_read()
+            try:
+                link_tree(target_tree, source_tree)
+            finally:
+                source_tree.unlock()
+        finally:
+            target_tree.unlock()
+
+
 commands = [
             cmd_baz_import,
             cmd_baz_import_branch,
@@ -649,6 +676,7 @@ commands = [
             cmd_fetch_ghosts,
             cmd_graph_ancestry,
             cmd_import,
+            cmd_link_tree,
             cmd_multi_pull,
             cmd_patch,
             cmd_rspush,
@@ -673,6 +701,8 @@ def test_suite():
     import bzrtools
     import tests.clean_tree
     import tests.is_clean
+    import tests.test_link_tree
+    import tests.test_patch
     import tests.test_rspush
     import tests.upstream_import
     import zap
@@ -692,5 +722,7 @@ def test_suite():
     result.addTest(tests.upstream_import.test_suite())
     result.addTest(zap.test_suite())
     result.addTest(TestLoader().loadTestsFromModule(tests.is_clean))
+    result.addTest(TestLoader().loadTestsFromModule(tests.test_link_tree))
+    result.addTest(TestLoader().loadTestsFromModule(tests.test_patch))
     result.addTest(TestLoader().loadTestsFromModule(tests.test_rspush))
     return result
