@@ -1,5 +1,5 @@
-# Copyright (C) 2006 Aaron Bentley
-# <aaron.bentley@utoronto.ca>
+# Copyright (C) 2006, 2008 Aaron Bentley
+# <aaron@aaronbentley.com>
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -25,7 +25,7 @@ from bzrlib import ui
 from bzrlib.urlutils import derive_to_location
 
 def cbranch(from_location, to_location=None, revision=None,
-            lightweight=False, files_from=None):
+            lightweight=False, files_from=None, hardlink=False):
     if to_location is None:
         to_location = derive_to_location(from_location)
     config = LocationConfig(abspath(to_location))
@@ -52,6 +52,7 @@ def cbranch(from_location, to_location=None, revision=None,
             accelerator_tree=accelerator_tree).open_branch()
         pb.update('Creating checkout', 1, 2)
         new_branch.create_checkout(to_location, lightweight=lightweight,
-                                   accelerator_tree=accelerator_tree)
+                                   accelerator_tree=accelerator_tree,
+                                   hardlink=hardlink)
     finally:
         pb.finished()
