@@ -1,5 +1,5 @@
 # Copyright (C) 2004, 2005 Aaron Bentley
-# <aaron.bentley@utoronto.ca>
+# <aaron@aaronbentley.com>
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -16,13 +16,10 @@
 #    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 from subprocess import Popen, PIPE
-from urllib import urlencode
-from xml.sax.saxutils import escape
 import os.path
 import errno
 import tempfile
 import shutil
-import time
 
 RSVG_OUTPUT_TYPES = ('png', 'jpg')
 DOT_OUTPUT_TYPES = ('svg', 'svgz', 'gif', 'jpg', 'ps', 'fig', 'mif', 'png',
