@@ -1,5 +1,5 @@
 # Copyright (C) 2005 Aaron Bentley, 2006 Michael Ellerman
-# <aaron.bentley@utoronto.ca>
+# <aaron@aaronbentley.com>
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -33,13 +33,13 @@ class PatchFailed(Exception):
 
 class PatchInvokeError(BzrError):
 
-    _fmt = """Error invoking patch: %(errstr)s\n%(stderr)s"""
+    _fmt = """Error invoking patch: %(errstr)s%(stderr)s"""
     internal_error = False
 
-    def __init__(self, e, stderr):
+    def __init__(self, e, stderr=''):
         self.exception = e
         self.errstr = os.strerror(e.errno)
-        self.stderr = stderr
+        self.stderr = '\n' + stderr
 
 
 class NoColor(Exception):
